import sys


from flask import Flask, render_template
import argparse
import os
from serve_swagger.util import  file_or_url_opener

parser = argparse.ArgumentParser()
petstore_url = "https://raw.githubusercontent.com/swagger-api/swagger-codegen/master/modules/swagger-codegen/src/test/resources/2_0/petstore.yaml"
default_spec_file = os.environ.get("DEFAULT_SWAGGER_SPECFILE",petstore_url)
parser.add_argument('swagger_spec_file',nargs="?",default=default_spec_file,
                    help="a local swagger spec file, or a url that serves a swagger spec file")
parser.add_argument("-p","--port",nargs="?",default=5000, type=int,help="the port to serve on")
parser.add_argument("-s","--host",nargs="?",default="127.0.0.1", help="the host interface to serve on")
parser.add_argument("-v","--debug",action='store_true', help="run flask in debug mode")
args = parser.parse_args()
app = Flask(__name__)




@app.route("/api.spec")
def read_spec():
    with file_or_url_opener(args.swagger_spec_file) as spec:
        return spec.read()


@app.route('/')
def hello_world():
    return render_template('api.html')

def serve():
    app.run(host=args.host, port=args.port, debug=args.debug)

if __name__ == '__main__':
    serve()



from contextlib import contextmanager
from serve_swagger.py23compat_local import urllib

@contextmanager
def urllib_urlopen(url):
    fh = urllib.urlopen(url)
    yield fh
    fh.close()

def file_or_url_opener(url_or_file):
    if url_or_file.startswith("http"):
        return urllib_urlopen(url_or_file)
    return open(url_or_file)


import sys

def is_py3():
    return sys.version_info[0] == 3
def is_py2():
    return sys.version_info[0] == 2

def open_file(fname,*args,**kwargs):

    if is_py3():
        return open(fname)

if is_py3():
    import urllib.request as urllib
else:
    import urllib





from setuptools import setup
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'readme.md')) as f:
    long_description = f.read()

setup(
    name='serve-swagger',
    version='1.3',
    url='https://github.com/joranbeasley/FlaskSwaggerAPIServer',
    license='GPL',
    author='Joran Beasley',
    author_email='joranbeasley@gmail.com',
    description='serve swagger api docs locally fast',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=['serve_swagger'],
    include_package_data=True,
    zip_safe=False,
    install_requires=['Flask'],
    entry_points={
        'console_scripts': ['serve-swagger=serve_swagger.app:serve']
    }
)
